#
# spec file for package pgbadger
#
# Copyright (c) 2013-2015 Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           pgbadger
Version:        8.1
Release:        2.17
License:        MIT
Summary:        A fast PostgreSQL log analyzer
Url:            http://dalibo.github.com/pgbadger/
Group:          System/Monitoring
Source:         pgbadger-%{version}.tar.gz
BuildRequires:  perl
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(IO::File)
BuildRequires:  perl(Benchmark)
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(Time::Local)
BuildRequires:  perl(Text::CSV_XS)
Requires:       perl(Getopt::Long)
Requires:       perl(IO::File)
Requires:       perl(Benchmark)
Requires:       perl(File::Basename)
Requires:       perl(Time::Local)
Requires:       perl = %{perl_version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
pgBadger is a PostgreSQL log analyzer build for speed with fully detailed
reports from your PostgreSQL log file. It's a single and small Perl script that
aims to replace and outperform the old php script pgFouine.

By the way, we would like to thank Guillaume Smet for all the work he has done
on this really nice tool. We've been using it a long time, it was a really
great tool!

pgBadger is written in pure Perl language. It uses a javascript library to draw
graphs so that you don't need additional Perl modules or any other package to
install. Furthermore, this library gives us more features such as zooming.

pgBadger is able to autodetect your log file format (syslog, stderr or csvlog).
It is designed to parse huge log files as well as gzip compressed file.
%prep
%setup -q

%build
perl Makefile.PL 
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
rmdir %{buildroot}%{perl_vendorarch} || : 
%if 0%{?suse_version} >= 01130
%perl_gen_filelist
%endif

%clean
rm -rf %{buildroot}

%if 0%{?suse_version} >= 01130
%files -f %{name}.files 
%defattr(-, root, root, -)
%doc ChangeLog README* LICENSE tools
%else
%files
%defattr(-, root, root, -)
%doc ChangeLog README* LICENSE tools
%{_bindir}/pgbadger
%dir %{perl_vendorarch}/auto/pgBadger
%{perl_vendorarch}/auto/pgBadger/.packlist
%{_mandir}/man1/pgbadger.1*
/var/adm/perl-modules/pgbadger
%endif

%changelog
* Mon Apr 25 2016 mrueckert@suse.de
- update to 8.1
  - Fix one case where pid file remain after dying.
  - Add requirement of log_error_verbosity = default to
    documentation.
  - Report message "LOG: using stale statistics instead of current
    ones because stats collector is not responding" in events view.
  - Remove obsolete days when we are in binary mode with --noreport
  - Fix wrong report of statements responsible of temporary files.
    Thanks to Luan Nicolini Marcondes for the report. This patch
    also exclude line with log level LOCATION to be parsed.
  - Fix limit on number of sample at report generation and remove
    pending LAST_PARSED.tmp file.
  - Update load_stat() function and global variables to support
    pgbouncer statistics. Update version to 2.0.
  - Handle more kind or query types. Thanks to julien Rouhaud for
    the patch.
  - Fix pgbouncer log parser to handle message: FATAL: the database
    system is shutting down
  - Fix whitespace placed in between the E and the quote character.
    Thanks to clijunky for the report.
  - Fix a major issue introduced with support to pgbouncer that
    prevent parsing of compressed PostgreSQL log files. Thanks to
    Levente Birta for the report.
- remove the unused rpmlintrc
* Sun Sep 13 2015 lars@linux-schulserver.de
- update to 7.1:
  + This new release fixes some issues and adds a new report:
  ++ Distribution of sessions per application
  + It also adds Json operators to SQL Beautifier.
  + this release also adds some more useful reports and features,
    please check the changes file in
    /usr/share/doc/packages/pgbadger/ChangeLog for details
- remove perl vendorarch directory if empty
- also package pgbadger_tools in doc directory
- add rpmlintrc to get rid of the license warning
* Tue Oct 14 2014 darin@darins.net
- update to 6.2
  + This is a maintenance release to fix a regression in SQL traffic graphs and
    fix some other minor issues.
  + The release also add a new option -D or --dns-resolv to map client ip addresses
    to FQDN without having log_hostname enabled on the postgresql's configuration
  + Do not display queries in Slowest individual, Time consuming and
    Normalized slowest queries reports when there is no duration in
    log file. Display NO DATASET instead.
  + Fix min/max queries in SQL traffic that was based on duration instead
    of query count.
  + Fix wrong unit to Synced files in Checkpoints files report. Thanks
    to Levente Birta for the report.
  + Enable allow_loose_quotes in Text::CSV_XS call to fix CSV parsing
    error when fields have quote inside an unquoted field. Thanks to
    Josh Berkus for the report.
  +- Add -D | --dns-resolv command line option to replace ip addresses
    by their DNS name. Be warned that this can slow down pgBagder a lot.
    Thanks to Jiri Hlinka for the feature request.
* Wed Mar 12 2014 lars@linux-schulserver.de
- update to 5.0:
  + This new major release adds some new features like incremental
    mode and SQL queries times histogram. There is also a hourly
    graphic representation of the count and average duration of top
    normalized queries.
  + there are many more changes, please refer to
    /usr/share/doc/packages/pgbadger/ChangeLog
    for details
* Mon May  6 2013 lars@linux-schulserver.de
- update to 3.3:
  * adds four more useful reports about queries that generate locks
    and temporary files
  * new report about restartpoint on slaves and several
  * adds escaping of HTML code inside queries
  * adds Min/Max reports with Average duration in all queries reports
  * many bug fixes
* Sat Mar 23 2013 lars@linux-schulserver.de
- update to 3.1:
  !! UPGRADE: if you are running pgbadger by cron take care if you
  !! were using one of the following option: --enable-log_min_duration
  !! and --enable-log_duration, they have been removed and pgbadger
  !! will refuse to start
  + This new major release adds parallel log processing by using as
    many cores as wanted to parse log files, the performances gain is
    directly related to the number of cores specified.
    There's also new reports about autovacuum/autoanalyze informations
    and many bugs have been fixed.
  + Please read the full Changelog at:
    /usr/share/doc/packages/pgbadger/ChangeLog
- do not use perl_gen_filelist macro on old distributions:
  breaks build
- removed duplicated perl(Text::CSV_XS) build requires line
* Wed Feb 13 2013 darin@darins.net
- update to 2.3
  * Clarify misleading statement about log_duration: log_duration may be
    turned on depending on desired information. Only log_statement must
    not be on. Thanks to Matt Romaine for the patch.
  * Fix --dbname and --dbuser not working with csvlog format. Thanks to
    Luke Cyca for the report.
  * Fix issue in SQL formatting that prevent left back indentation when
    major keywords were found. Thanks to Kevin Brannen for the report.
  * Display 3 decimals in time report so that ms can be seen. Thanks to
    Adam Schroder for the request.
  * Force the parser to not insert a new line after the SET keyword when
    the query begin with it. This is to preserve the single line with
    queries like SET client_encoding TO "utf8";
  * Add better SQL formatting of update queries by adding a new line
    after the SET keyword. Thanks to pilat66 for the report.
  * Update copyright and documentation.
  * See ChangeLog
- added missing perl dependency for cvs logs
* Sun Jan  6 2013 lars@linux-schulserver.de
- initial version 2.2-1
